==> applet-service-2.0.0-20190923.023948-1-sources.jar: com/bizvane/appletservice/models/bo/MktConvertCouponRecordBo.java <==
package com.bizvane.appletservice.models.bo;

import io.swagger.annotations.ApiModelProperty;

import java.util.Date;

public class MktConvertCouponRecordBo {
    @ApiModelProperty(
            value = "券兑换记录id",
            name = "convertCouponRecordId",
            required = false,
            example = ""
    )
    private Long convertCouponRecordId;
    @ApiModelProperty(
            value = "券兑换记录code",
            name = "convertCouponRecordCode",
            required = false,
            example = ""
    )
    private String convertCouponRecordCode;
    @ApiModelProperty(
            value = "兑换规则id",
            name = "exchangeId",
            required = false,
            example = ""
    )
    private Long exchangeId;
    @ApiModelProperty(
            value = "兑换规则code",
            name = "exchangeCode",
            required = false,
            example = ""
    )
    private String exchangeCode;
    @ApiModelProperty(
            value = "公司id",
            name = "sysCompanyId",
            required = false,
            example = ""
    )
    private Long sysCompanyId;
    @ApiModelProperty(
            value = "品牌id",
            name = "sysBrandId",
            required = false,
            example = ""
    )
    private Long sysBrandId;
    @ApiModelProperty(
            value = "会员姓名",
            name = "memberName",
            required = false,
            example = ""
    )
    private String memberName;
    @ApiModelProperty(
            value = "会员code",
            name = "memberCode",
            required = false,
            example = ""
    )
    private String memberCode;
    @ApiModelProperty(
            value = "券编号",
            name = "cardNo",
            required = false,
            example = ""
    )
    private String cardNo;
    @ApiModelProperty(
            value = "券名称",
            name = "couponName",
            required = false,
            example = ""
    )
    private String couponName;
    @ApiModelProperty(
            value = "券id",
            name = "couponEntityId",
            required = false,
            example = ""
    )
    private Long couponEntityId;
    @ApiModelProperty(
            value = "券数量",
            name = "couponNum",
            required = false,
            example = ""
    )
    private Integer couponNum;
    @ApiModelProperty(
            value = "兑换券的积分数量",
            name = "convertPrice",
            required = false,
            example = ""
    )
    private Integer convertPrice;
    @ApiModelProperty(
            value = "兑换的券数量",
            name = "convertNum",
            required = false,
            example = ""
    )
    private Integer convertNum;
    @ApiModelProperty(
            value = "会员兑换券所用积分",
            name = "convertTatalIntegral",
            required = false,
            example = ""
    )
    private Integer convertTatalIntegral;
    @ApiModelProperty(
            value = "兑换时间",
            name = "convertTime",
            required = false,
            example = ""
    )
    private Date convertTime;
    @ApiModelProperty(
            value = "是否成功:1成功 0失败",
            name = "successType",
            required = false,
            example = ""
    )
    private Boolean successType;
    @ApiModelProperty(
            value = "",
            name = "createUserId",
            required = false,
            example = ""
    )
    private Long createUserId;
    @ApiModelProperty(
            value = "",
            name = "createUserName",
            required = false,
            example = ""
    )
    private String createUserName;
    @ApiModelProperty(
            value = "",
            name = "createDate",
            required = false,
            example = ""
    )
    private Date createDate;
    @ApiModelProperty(
            value = "",
            name = "modifiedUserId",
            required = false,
            example = ""
    )
    private Long modifiedUserId;
    @ApiModelProperty(
            value = "",
            name = "modifiedUserName",
            required = false,
            example = ""
    )
    private String modifiedUserName;
    @ApiModelProperty(
            value = "",
            name = "modifiedDate",
            required = false,
            example = ""
    )
    private Date modifiedDate;
    @ApiModelProperty(
            value = "数据有效性：1有效；0无效",
            name = "valid",
            required = false,
            example = ""
    )
    private Boolean valid;
    @ApiModelProperty(
            value = "券code",
            name = "couponCodes",
            required = false,
            example = ""
    )
    private String couponCodes;
    private static final long serialVersionUID = 1L;
    private String couponImg;
    private String preferentialType;
    private String money;
    private String discount;

    public Long getConvertCouponRecordId() {
        return convertCouponRecordId;
    }

    public void setConvertCouponRecordId(Long convertCouponRecordId) {
        this.convertCouponRecordId = convertCouponRecordId;
    }

    public String getConvertCouponRecordCode() {
        return convertCouponRecordCode;
    }

    public void setConvertCouponRecordCode(String convertCouponRecordCode) {
        this.convertCouponRecordCode = convertCouponRecordCode;
    }

    public Long getExchangeId() {
        return exchangeId;
    }

    public void setExchangeId(Long exchangeId) {
        this.exchangeId = exchangeId;
    }

    public String getExchangeCode() {
        return exchangeCode;
    }

    public void setExchangeCode(String exchangeCode) {
        this.exchangeCode = exchangeCode;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public String getMemberName() {
        return memberName;
    }

    public void setMemberName(String memberName) {
        this.memberName = memberName;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }

    public String getCardNo() {
        return cardNo;
    }

    public void setCardNo(String cardNo) {
        this.cardNo = cardNo;
    }

    public String getCouponName() {
        return couponName;
    }

    public void setCouponName(String couponName) {
        this.couponName = couponName;
    }

    public Long getCouponEntityId() {
        return couponEntityId;
    }

    public void setCouponEntityId(Long couponEntityId) {
        this.couponEntityId = couponEntityId;
    }

    public Integer getCouponNum() {
        return couponNum;
    }

    public void setCouponNum(Integer couponNum) {
        this.couponNum = couponNum;
    }

    public Integer getConvertPrice() {
        return convertPrice;
    }

    public void setConvertPrice(Integer convertPrice) {
        this.convertPrice = convertPrice;
    }

    public Integer getConvertNum() {
        return convertNum;
    }

    public void setConvertNum(Integer convertNum) {
        this.convertNum = convertNum;
    }

    public Integer getConvertTatalIntegral() {
        return convertTatalIntegral;
    }

    public void setConvertTatalIntegral(Integer convertTatalIntegral) {
        this.convertTatalIntegral = convertTatalIntegral;
    }

    public Date getConvertTime() {
        return convertTime;
    }

    public void setConvertTime(Date convertTime) {
        this.convertTime = convertTime;
    }

    public Boolean getSuccessType() {
        return successType;
    }

    public void setSuccessType(Boolean successType) {
        this.successType = successType;
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public Long getModifiedUserId() {
        return modifiedUserId;
    }

    public void setModifiedUserId(Long modifiedUserId) {
        this.modifiedUserId = modifiedUserId;
    }

    public String getModifiedUserName() {
        return modifiedUserName;
    }

    public void setModifiedUserName(String modifiedUserName) {
        this.modifiedUserName = modifiedUserName;
    }

    public Date getModifiedDate() {
        return modifiedDate;
    }

    public void setModifiedDate(Date modifiedDate) {
        this.modifiedDate = modifiedDate;
    }

    public Boolean getValid() {
        return valid;
    }

    public void setValid(Boolean valid) {
        this.valid = valid;
    }

    public String getCouponCodes() {
        return couponCodes;
    }

    public void setCouponCodes(String couponCodes) {
        this.couponCodes = couponCodes;
    }

    public static long getSerialVersionUID() {
        return serialVersionUID;
    }

    public String getCouponImg() {
        return couponImg;
    }

    public void setCouponImg(String couponImg) {
        this.couponImg = couponImg;
    }

    public String getPreferentialType() {
        return preferentialType;
    }

    public void setPreferentialType(String preferentialType) {
        this.preferentialType = preferentialType;
    }

    public String getMoney() {
        return money;
    }

    public void setMoney(String money) {
        this.money = money;
    }

    public String getDiscount() {
        return discount;
    }

    public void setDiscount(String discount) {
        this.discount = discount;
    }
}

==> applet-service-2.0.0-20200817.093941-19-sources.jar: com/bizvane/appletservice/models/bo/MktConvertCouponRecordBo.java <==
package com.bizvane.appletservice.models.bo;

import io.swagger.annotations.ApiModelProperty;

import java.util.Date;

public class MktConvertCouponRecordBo {
    @ApiModelProperty(
            value = "券兑换记录id",
            name = "convertCouponRecordId",
            required = false,
            example = ""
    )
    private Long convertCouponRecordId;
    @ApiModelProperty(
            value = "券兑换记录code",
            name = "convertCouponRecordCode",
            required = false,
            example = ""
    )
    private String convertCouponRecordCode;
    @ApiModelProperty(
            value = "兑换规则id",
            name = "exchangeId",
            required = false,
            example = ""
    )
    private Long exchangeId;
    @ApiModelProperty(
            value = "兑换规则code",
            name = "exchangeCode",
            required = false,
            example = ""
    )
    private String exchangeCode;
    @ApiModelProperty(
            value = "公司id",
            name = "sysCompanyId",
            required = false,
            example = ""
    )
    private Long sysCompanyId;
    @ApiModelProperty(
            value = "品牌id",
            name = "sysBrandId",
            required = false,
            example = ""
    )
    private Long sysBrandId;
    @ApiModelProperty(
            value = "会员姓名",
            name = "memberName",
            required = false,
            example = ""
    )
    private String memberName;
    @ApiModelProperty(
            value = "会员code",
            name = "memberCode",
            required = false,
            example = ""
    )
    private String memberCode;
    @ApiModelProperty(
            value = "券编号",
            name = "cardNo",
            required = false,
            example = ""
    )
    private String cardNo;
    @ApiModelProperty(
            value = "券名称",
            name = "couponName",
            required = false,
            example = ""
    )
    private String couponName;
    @ApiModelProperty(
            value = "券id",
            name = "couponEntityId",
            required = false,
            example = ""
    )
    private Long couponEntityId;
    @ApiModelProperty(
            value = "券数量",
            name = "couponNum",
            required = false,
            example = ""
    )
    private Integer couponNum;
    @ApiModelProperty(
            value = "兑换券的积分数量",
            name = "convertPrice",
            required = false,
            example = ""
    )
    private Integer convertPrice;
    @ApiModelProperty(
            value = "兑换的券数量",
            name = "convertNum",
            required = false,
            example = ""
    )
    private Integer convertNum;
    @ApiModelProperty(
            value = "会员兑换券所用积分",
            name = "convertTatalIntegral",
            required = false,
            example = ""
    )
    private Integer convertTatalIntegral;
    @ApiModelProperty(
            value = "兑换时间",
            name = "convertTime",
            required = false,
            example = ""
    )
    private Date convertTime;
    @ApiModelProperty(
            value = "是否成功:1成功 0失败",
            name = "successType",
            required = false,
            example = ""
    )
    private Boolean successType;
    @ApiModelProperty(
            value = "",
            name = "createUserId",
            required = false,
            example = ""
    )
    private Long createUserId;
    @ApiModelProperty(
            value = "",
            name = "createUserName",
            required = false,
            example = ""
    )
    private String createUserName;
    @ApiModelProperty(
            value = "",
            name = "createDate",
            required = false,
            example = ""
    )
    private Date createDate;
    @ApiModelProperty(
            value = "",
            name = "modifiedUserId",
            required = false,
            example = ""
    )
    private Long modifiedUserId;
    @ApiModelProperty(
            value = "",
            name = "modifiedUserName",
            required = false,
            example = ""
    )
    private String modifiedUserName;
    @ApiModelProperty(
            value = "",
            name = "modifiedDate",
            required = false,
            example = ""
    )
    private Date modifiedDate;
    @ApiModelProperty(
            value = "数据有效性：1有效；0无效",
            name = "valid",
            required = false,
            example = ""
    )
    private Boolean valid;
    @ApiModelProperty(
            value = "券code",
            name = "couponCodes",
            required = false,
            example = ""
    )
    private Integer integralExchangeType;
    @ApiModelProperty(
            value = "兑换类型",
            name = "integralExchangeType",
            required = false,
            example = ""
    )
    private String couponCodes;
    private static final long serialVersionUID = 1L;
    private String couponImg;
    private String preferentialType;
    private String money;
    private String discount;

    public Long getConvertCouponRecordId() {
        return convertCouponRecordId;
    }

    public void setConvertCouponRecordId(Long convertCouponRecordId) {
        this.convertCouponRecordId = convertCouponRecordId;
    }

    public String getConvertCouponRecordCode() {
        return convertCouponRecordCode;
    }

    public void setConvertCouponRecordCode(String convertCouponRecordCode) {
        this.convertCouponRecordCode = convertCouponRecordCode;
    }

    public Long getExchangeId() {
        return exchangeId;
    }

    public void setExchangeId(Long exchangeId) {
        this.exchangeId = exchangeId;
    }

    public String getExchangeCode() {
        return exchangeCode;
    }

    public void setExchangeCode(String exchangeCode) {
        this.exchangeCode = exchangeCode;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public String getMemberName() {
        return memberName;
    }

    public void setMemberName(String memberName) {
        this.memberName = memberName;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }

    public String getCardNo() {
        return cardNo;
    }

    public void setCardNo(String cardNo) {
        this.cardNo = cardNo;
    }

    public String getCouponName() {
        return couponName;
    }

    public void setCouponName(String couponName) {
        this.couponName = couponName;
    }

    public Long getCouponEntityId() {
        return couponEntityId;
    }

    public void setCouponEntityId(Long couponEntityId) {
        this.couponEntityId = couponEntityId;
    }

    public Integer getCouponNum() {
        return couponNum;
    }

    public void setCouponNum(Integer couponNum) {
        this.couponNum = couponNum;
    }

    public Integer getConvertPrice() {
        return convertPrice;
    }

    public void setConvertPrice(Integer convertPrice) {
        this.convertPrice = convertPrice;
    }

    public Integer getConvertNum() {
        return convertNum;
    }

    public void setConvertNum(Integer convertNum) {
        this.convertNum = convertNum;
    }

    public Integer getConvertTatalIntegral() {
        return convertTatalIntegral;
    }

    public void setConvertTatalIntegral(Integer convertTatalIntegral) {
        this.convertTatalIntegral = convertTatalIntegral;
    }

    public Date getConvertTime() {
        return convertTime;
    }

    public void setConvertTime(Date convertTime) {
        this.convertTime = convertTime;
    }

    public Boolean getSuccessType() {
        return successType;
    }

    public void setSuccessType(Boolean successType) {
        this.successType = successType;
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public Long getModifiedUserId() {
        return modifiedUserId;
    }

    public void setModifiedUserId(Long modifiedUserId) {
        this.modifiedUserId = modifiedUserId;
    }

    public String getModifiedUserName() {
        return modifiedUserName;
    }

    public void setModifiedUserName(String modifiedUserName) {
        this.modifiedUserName = modifiedUserName;
    }

    public Date getModifiedDate() {
        return modifiedDate;
    }

    public void setModifiedDate(Date modifiedDate) {
        this.modifiedDate = modifiedDate;
    }

    public Boolean getValid() {
        return valid;
    }

    public void setValid(Boolean valid) {
        this.valid = valid;
    }

    public String getCouponCodes() {
        return couponCodes;
    }

    public void setCouponCodes(String couponCodes) {
        this.couponCodes = couponCodes;
    }

    public static long getSerialVersionUID() {
        return serialVersionUID;
    }

    public String getCouponImg() {
        return couponImg;
    }

    public void setCouponImg(String couponImg) {
        this.couponImg = couponImg;
    }

    public String getPreferentialType() {
        return preferentialType;
    }

    public void setPreferentialType(String preferentialType) {
        this.preferentialType = preferentialType;
    }

    public String getMoney() {
        return money;
    }

    public void setMoney(String money) {
        this.money = money;
    }

    public String getDiscount() {
        return discount;
    }

    public void setDiscount(String discount) {
        this.discount = discount;
    }

    public Integer getIntegralExchangeType() {
        return integralExchangeType;
    }

    public void setIntegralExchangeType(Integer integralExchangeType) {
        this.integralExchangeType = integralExchangeType;
    }
}
